@@ -18,6 +18,19 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+/**
+ * SECTION:element-fsselector:
+ *
+ * The #fsselector element has one sink and one source pad. It will look for
+ * other elements that also have one sink and one source pad.
+ * It will then pick an element that matches the caps on both sides.
+ * If the caps change, it may change the selected element if the current one
+ * no longer matches the caps.
+ *
+ * The list of element it will look into can be specified in the
+ * #FsSelector::factories property, otherwise it will look at all available
+ * elements.
+ */
 
 #include "fsselector.h"
 
@@ -104,8 +117,6 @@ static gboolean fs_selector_internal_sink_event (GstPad *pad, GstEvent *event);
 static gboolean fs_selector_internal_sink_query (GstPad *pad, GstQuery *query);
 static const GstQueryType* fs_selector_internal_sink_query_type (GstPad *pad);
 static GstCaps* fs_selector_internal_sink_getcaps (GstPad *pad);
-static gboolean fs_selector_internal_sink_acceptcaps (GstPad *pad,
-    GstCaps *caps);
 static GstFlowReturn fs_selector_internal_sink_buffer_alloc (GstPad *pad,
     guint64 offset, guint size, GstCaps *caps, GstBuffer **buf);
 static void fs_selector_internal_sink_fixatecaps (GstPad *pad, GstCaps *caps);
@@ -506,8 +517,6 @@ fs_selector_add_element (FsSelector *selector, GstElementFactory *factory)
       GST_DEBUG_FUNCPTR (fs_selector_internal_sink_query_type));
   gst_pad_set_getcaps_function (internal_sinkpad,
       GST_DEBUG_FUNCPTR (fs_selector_internal_sink_getcaps));
-  gst_pad_set_acceptcaps_function (internal_sinkpad,
-      GST_DEBUG_FUNCPTR (fs_selector_internal_sink_acceptcaps));
   gst_pad_set_bufferalloc_function (internal_sinkpad,
       GST_DEBUG_FUNCPTR (fs_selector_internal_sink_buffer_alloc));
   gst_pad_set_fixatecaps_function (internal_sinkpad,
@@ -1267,16 +1276,7 @@ fs_selector_internal_sink_getcaps (GstPad *pad)
   FsSelector *selector = FS_SELECTOR (g_object_get_qdata (G_OBJECT (pad),
           parent_quark));
 
-  return gst_pad_get_caps (selector->srcpad);
-}
-
-static gboolean
-fs_selector_internal_sink_acceptcaps (GstPad *pad, GstCaps *caps)
-{
-  FsSelector *selector = FS_SELECTOR (g_object_get_qdata (G_OBJECT (pad),
-          parent_quark));
-
-  return gst_pad_accept_caps (selector->srcpad, caps);
+  return gst_pad_peer_get_caps (selector->srcpad);
 }
 
 static void
@@ -1349,7 +1349,7 @@ gboolean
 fs_selector_plugin_init (GstPlugin *plugin)
 {
   return gst_element_register (plugin, "fsselector",
-      GST_RANK_MARGINAL, FS_TYPE_SELECTOR);
+      GST_RANK_NONE, FS_TYPE_SELECTOR);
 }
 
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
